==> enterprisemodules-wls_config-3.3.15.tar.gz: enterprisemodules-wls_config-3.3.15/lib/puppet/type/wls_jms_subdeployment.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_subdeployment) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a JMS subdeployment in a JMS module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_subdeployment { 'jmsClusterModule:jmsServers':
          ensure     => 'present',
          target     => ['jmsServer1','jmsServer2'],
          targettype => ['JMSServer','JMSServer'],
        }

    In this example you are managing a JMS subdeployment in the default domain. When you want to
    manage a JMS subdeployment in a specific domain, you can use:

        wls_jms_subdeployment { 'my_domain/jmsClusterModule:wlsServers':
          ensure     => 'present',
          target     => ['WebCluster'],
          targettype => ['Cluster'],
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/SubDeployments')
    bean_type('SubDeployment')

    ensurable
    parameter :subdeployment_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout
    property :target
    property :targettype
    extraproperties do
      property :module_type
      property :compatibility_name
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
      property :untargeted
    end

    add_title_attributes(:jmsmodule, :subdeployment_name) do
      /(.+):(.+)/
    end
  end
end

==> enterprisemodules-wls_config-3.20.0.tar.gz: enterprisemodules-wls_config-3.20.0/lib/puppet/type/wls_jms_subdeployment.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_subdeployment) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESCC
    This resource allows you to manage a JMS subdeployment in a JMS module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_subdeployment { 'jmsClusterModule:jmsServers':
          ensure     => 'present',
          target     => ['jmsServer1','jmsServer2'],
          targettype => ['JMSServer','JMSServer'],
        }

    In this example you are managing a JMS subdeployment in the default domain. When you want to
    manage a JMS subdeployment in a specific domain, you can use:

        wls_jms_subdeployment { 'my_domain/jmsClusterModule:wlsServers':
          ensure     => 'present',
          target     => ['WebCluster'],
          targettype => ['Cluster'],
        }

    DESCC

    bean_path('/JMSSystemResources/%<jmsmodule>s/SubDeployments')
    bean_type('SubDeployment')

    ensurable
    parameter :subdeployment_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout
    property :target
    property :targettype
    extraproperties do
      property :module_type
      property :compatibility_name
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
      property :untargeted
    end

    add_title_attributes(:jmsmodule, :subdeployment_name) do
      /(.+):(.+)/
    end
  end
end
